@@ -4,7 +4,7 @@
 // Author:
 //   Steffen Macke (sdteffen@sdteffen.de)
 //
-// Copyright (C) 2007, 2009 - 2012 Steffen Macke (http://dia-installer.de)
+// Copyright (C) 2007, 2009 - 2013 Steffen Macke (http://dia-installer.de)
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-
 using System;
 using System.Xml.XPath;
 using System.Xml;
@@ -32,6 +31,7 @@ class DiaIcons
 {
   public const string SHEET_SPECIFIC = "SHEET_SPECIFIC";
   public SortedDictionary < string, string > icons;
+  public String fullpath = "";
 
   // Parse the available icons
   public DiaIcons ()
@@ -40,36 +40,46 @@ class DiaIcons
     string[] folders =
     {
     "sheets", "shapes"};
-    var fullpath = new DirectoryInfo (".").FullName;
+    fullpath = new DirectoryInfo (".").FullName;
     foreach (string folder in folders)
     {
       DirectoryInfo dir = new DirectoryInfo (folder);
       foreach (DirectoryInfo d in dir.GetDirectories ())
       {
-	foreach (FileInfo f in d.GetFiles ("*.png"))
+	GetPngsInDir (d);
+	foreach (DirectoryInfo s in d.GetDirectories ())
 	{
-	  var path = f.FullName.Replace (fullpath + "/", "");
-	  string duplicatevalue;
-	  if (icons.TryGetValue (f.Name, out duplicatevalue))
+	  GetPngsInDir (s);
+	}
+      }
+    }
+  }
+
+  public void GetPngsInDir (DirectoryInfo d)
+  {
+
+    foreach (FileInfo f in d.GetFiles ("*.png"))
+    {
+      var path = f.FullName.Replace (fullpath + "/", "");
+      string duplicatevalue;
+      if (icons.TryGetValue (f.Name, out duplicatevalue))
+	{
+	  if (SHEET_SPECIFIC != duplicatevalue)
 	    {
-	      if (SHEET_SPECIFIC != duplicatevalue)
-		{
-		  icons.Add (DiaCss.CanonicalizePath (duplicatevalue),
-			     duplicatevalue);
-		  icons.Add (DiaCss.CanonicalizePath (path), path);
-		  icons[f.Name] = SHEET_SPECIFIC;
-		}
-	      else
-		{
-		  icons.Add (DiaCss.CanonicalizePath (path), path);
-		}
+	      icons.Add (DiaCss.CanonicalizePath (duplicatevalue),
+			 duplicatevalue);
+	      icons.Add (DiaCss.CanonicalizePath (path), path);
+	      icons[f.Name] = SHEET_SPECIFIC;
 	    }
 	  else
 	    {
-	      icons.Add (f.Name, path);
+	      icons.Add (DiaCss.CanonicalizePath (path), path);
 	    }
 	}
-      }
+      else
+	{
+	  icons.Add (f.Name, path);
+	}
     }
   }
 }
@@ -96,6 +106,7 @@ class DiaIconFinder
 
   public DiaIconFinder ()
   {
+
     icons = new DiaIcons ();
     objecticons = new Dictionary < string, string > ();
     objectsheets = new Dictionary < string, string > ();
@@ -133,37 +144,46 @@ class DiaIconFinder
     System.IO.DirectoryInfo sdir = new System.IO.DirectoryInfo ("shapes");
     foreach (System.IO.DirectoryInfo idir in sdir.GetDirectories ())
     {
-      foreach (System.IO.FileInfo f in idir.GetFiles ("*.shape"))
+      GetShapesInDir (idir);
+      foreach (System.IO.DirectoryInfo jdir in idir.GetDirectories ())
       {
-	XmlDocument shape = new XmlDocument ();
-	shape.Load (f.FullName);
-	XmlNamespaceManager nsmgr = new XmlNamespaceManager (shape.NameTable);
-	nsmgr.AddNamespace ("", "http://www.daa.com.au/~james/dia-shape-ns");
-	XmlNodeList nodeList;
-	nodeList =
-	  shape.GetElementsByTagName ("name",
-				      "http://www.daa.com.au/~james/dia-shape-ns");
-	foreach (XmlNode name in nodeList)
-	{
-	  string dummy;
-	  if ((name.ParentNode.Name == "shape")
-	      && !(objecticons.TryGetValue (name.InnerText, out dummy)))
-	    {
-	      XmlNodeList iconList;
-	      iconList =
-		shape.GetElementsByTagName ("icon",
-					    "http://www.daa.com.au/~james/dia-shape-ns");
-	      foreach (XmlNode icon in iconList)
-	      {
-		objecticons.Add (name.InnerText, icon.InnerText);
-	      }
-	    }
-	}
-
+	GetShapesInDir (jdir);
       }
     }
   }
 
+  public void GetShapesInDir (System.IO.DirectoryInfo idir)
+  {
+    foreach (System.IO.FileInfo f in idir.GetFiles ("*.shape"))
+    {
+      XmlDocument shape = new XmlDocument ();
+      shape.Load (f.FullName);
+      XmlNamespaceManager nsmgr = new XmlNamespaceManager (shape.NameTable);
+      nsmgr.AddNamespace ("", "http://www.daa.com.au/~james/dia-shape-ns");
+      XmlNodeList nodeList;
+      nodeList =
+	shape.GetElementsByTagName ("name",
+				    "http://www.daa.com.au/~james/dia-shape-ns");
+      foreach (XmlNode name in nodeList)
+      {
+	string dummy;
+	if ((name.ParentNode.Name == "shape")
+	    && !(objecticons.TryGetValue (name.InnerText, out dummy)))
+	  {
+	    XmlNodeList iconList;
+	    iconList =
+	      shape.GetElementsByTagName ("icon",
+					  "http://www.daa.com.au/~james/dia-shape-ns");
+	    foreach (XmlNode icon in iconList)
+	    {
+	      objecticons.Add (name.InnerText, icon.InnerText);
+	    }
+	  }
+      }
+
+    }
+  }
+
   // For a given Dia object, return the matching CSS class
   public string GetClassForObjectName (string name)
   {
@@ -173,42 +193,177 @@ class DiaIconFinder
 
     switch (name)
       {
-case "AADL - Box":  
+      case "AADL - Box":
 	cssclass = "daadlprocess";
 	break;
-    case "AADL - Process":
-      cssclass = "daadlprocess";
-	    break;
-    case "AADL - Thread":
-      cssclass = "daadlthread";
+      case "AADL - Process":
+	cssclass = "daadlprocess";
 	break;
-    case "AADL - Data":
-      cssclass = "daadldata";
+      case "AADL - Thread":
+	cssclass = "daadlthread";
 	break;
-    case "AADL - Processor":
-      cssclass = "daadlprocessor";
+      case "AADL - Data":
+	cssclass = "daadldata";
 	break;
-    case "AADL - Memory":
-      cssclass = "daadlmemory";
+      case "AADL - Processor":
+	cssclass = "daadlprocessor";
 	break;
-    case "AADL - Bus":
-      cssclass = "daadlbus";
+      case "AADL - Memory":
+	cssclass = "daadlmemory";
 	break;
-    case "AADL - System":
-      cssclass = "daadlsystem";
+      case "AADL - Bus":
+	cssclass = "daadlbus";
 	break;
-    case "AADL - Subprogram":
-      cssclass = "daadlsubprogram";
+      case "AADL - System":
+	cssclass = "daadlsystem";
 	break;
-    case "AADL - Thread Group":
-      cssclass = "daadlthreadgroup";
+      case "AADL - Subprogram":
+	cssclass = "daadlsubprogram";
 	break;
-    case "AADL - Device":
-      cssclass = "daadldevice";
+      case "AADL - Thread Group":
+	cssclass = "daadlthreadgroup";
 	break;
-    case "AADL - Package":
+      case "AADL - Device":
+	cssclass = "daadldevice";
+	break;
+      case "AADL - Package":
 	cssclass = "daadlpackage";
 	break;
+      case "chronogram - reference":
+	cssclass = "dchronoref";
+	break;
+      case "chronogram - line":
+	cssclass = "dchronoline";
+	break;
+      case "Database - Table":
+	cssclass = "dtable";
+	break;
+      case "Database - Reference":
+	cssclass = "dreference";
+	break;
+      case "Database - Compound":
+	cssclass = "dcompound";
+	break;
+      case "ER - Entity":
+	cssclass = "dc2sheetentity";
+	break;
+      case "ER - Relationship":
+	cssclass = "drelationship";
+	break;
+      case "ER - Attribute":
+	cssclass = "dattribute";
+	break;
+      case "ER - Participation":
+	cssclass = "dparticipation";
+	break;
+      case "Flowchart - Box":
+	cssclass = "dAssortedsquare";
+	break;
+      case "Flowchart - Parallelogram":
+	cssclass = "dpgram";
+	break;
+      case "Flowchart - Diamond":
+	cssclass = "dc2sheetdiamond";
+	break;
+      case "Flowchart - Ellipse":
+	cssclass = "dcircle";
+	break;
+      case "FS - Flow":
+	cssclass = "dflow";
+	break;
+      case "FS - Orthflow":
+	cssclass = "dorthflow";
+	break;
+      case "FS - Function":
+	cssclass = "dc2sheetfunction";
+	break;
+      case "GRAFCET - Step":
+	cssclass = "detape";
+	break;
+      case "GRAFCET - Action":
+	cssclass = "daction";
+	break;
+      case "GRAFCET - Condition":
+	cssclass = "dc2sheetcondition";
+	break;
+      case "GRAFCET - Transition":
+	cssclass = "dtransition";
+	break;
+      case "GRAFCET - Vergent":
+	cssclass = "dvergent";
+	break;
+      case "GRAFCET - Arc":
+	cssclass = "dvector";
+	break;
+      case "Istar - goal":
+	cssclass = "dc2sheetgoal";
+	break;
+      case "Istar - other":
+	cssclass = "dresource";
+	break;
+      case "Istar - actor":
+	cssclass = "dactor";
+	break;
+      case "Istar - link":
+	cssclass = "dlink";
+	break;
+      case "KAOS - other":
+	cssclass = "dc2sheetagent";
+	break;
+      case "KAOS - goal":
+	cssclass = "dKAOSsoftgoal";
+	break;
+      case "KAOS - maor":
+	cssclass = "dand-ref";
+	break;
+      case "KAOS - mbr":
+	cssclass = "dobstructs";
+	break;
+      case "Jackson - domain":
+	cssclass = "dgiven_domain";
+	break;
+      case "Jackson - requirement":
+	cssclass = "dc2sheetrequirement";
+	break;
+      case "Jackson - phenomenon":
+	cssclass = "dshared_phen";
+	break;
+      case "Misc - Tree":
+	cssclass = "dtree";
+	break;
+      case "Misc - Analog Clock":
+	cssclass = "danalog_clock";
+	break;
+      case "Misc - Measure":
+	cssclass = "dc2sheetmeasure";
+	break;
+      case "Misc - Grid":
+	cssclass = "dgrid_object";
+	break;
+      case "Network - Bus":
+	cssclass = "dbus";
+	break;
+      case "Network - WAN Link":
+	cssclass = "dwanlink";
+	break;
+      case "Network - Base Station":
+	cssclass = "dbasestation";
+	break;
+      case "Network - Radio Cell":
+	cssclass = "dradiocell";
+	break;
+      case "Network - Laptop Computer":
+	cssclass = "dlaptop";
+	break;
+      case "SADT - arrow":
+	cssclass = "darrow";
+	break;
+      case "SADT - box":
+	cssclass = "dsadtbox";
+	break;
+      case "SADT - annotation":
+	cssclass = "dannotation";
+	break;
       case "UML - Class":
 	cssclass = "dumlclass";
 	break;
@@ -293,8 +448,23 @@ case "AADL - Box":
 		  {
 		    if (objectsheets.TryGetValue (name, out sheet))
 		      {
+			// Some shape directories are split into several sheets
+			string shape4sheet = sheet;
+			switch (sheet)
+			  {
+			  case "ciscocomputer":
+			  case "ciscohub":
+			  case "ciscomisc":
+			  case "cisconetwork":
+			  case "ciscotelephony":
+			    shape4sheet = "Cisco";
+			    break;
+			  case "network":
+			    shape4sheet = "Network";
+			    break;
+			  }
 			cssclass =
-			  "d" + sheet +
+			  "d" + shape4sheet +
 			  DiaCss.CanonicalizePath (cssclass).Replace (".png",
 								      "");
 		      }
