@@ -4,7 +4,7 @@
 // Author:
 //   Steffen Macke (sdteffen@sdteffen.de)
 //
-// Copyright (C) 2007, 2009 - 2012 Steffen Macke (http://dia-installer.de)
+// Copyright (C) 2007, 2009 - 2013 Steffen Macke (http://dia-installer.de)
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -35,29 +35,25 @@ public class Sheet2Html
       {
 	Console.Error.WriteLine ("USAGE: sheet2html [options] [sheetname]");
 	Console.Error.WriteLine ("Options:");
-	Console.
-	  Error.WriteLine
+	Console.Error.WriteLine
 	  ("--author=AUTHOR            Specify sheet creator");
-	Console.
-	  Error.WriteLine
+	Console.Error.WriteLine
 	  ("--comes-with-dia           Sheet is part of the Dia distribution");
-	Console.
-	  Error.WriteLine
-	  ("--datadir=datadir			Path where sheets and shapes reside");
-	Console.
-	  Error.WriteLine
+	Console.Error.WriteLine
+	  ("--datadir=datadir          Path where sheets and shapes reside");
+	Console.Error.WriteLine
+	  ("--example-author=AUTHOR     Specify example author");
+	Console.Error.WriteLine
 	  ("-h, --help                 Display help and exit");
-	Console.
-	  Error.WriteLine
+	Console.Error.WriteLine
+	  ("--original-example=URL     Link to the original example file");
+	Console.Error.WriteLine
 	  ("--output-directory=DIR     Specify output directory");
-	Console.
-	  Error.WriteLine
+	Console.Error.WriteLine
 	  ("--noads                    Add noads tags to template");
-	Console.
-	  Error.WriteLine
+	Console.Error.WriteLine
 	  ("--tpl                      Create Smarty Template");
-	Console.
-	  Error.WriteLine
+	Console.Error.WriteLine
 	  ("-v, --version              Display version and exit");
 
 	return;
@@ -65,19 +61,21 @@ public class Sheet2Html
 
     if ("-v" == args[0] || "--version" == args[0])
       {
-	Console.Error.WriteLine ("sheet2html 0.9.2");
-	Console.
-	  Error.WriteLine ("Copyright (c) 2007, 2009 - 2012 Steffen Macke");
+	Console.Error.WriteLine ("sheet2html 0.9.3");
+	Console.Error.
+	  WriteLine ("Copyright (c) 2007, 2009 - 2013 Steffen Macke");
 	return;
       }
 
     // Defaults
     System.IO.DirectoryInfo outputdir = new System.IO.DirectoryInfo (".");
     string author = "";
+    string exampleauthor = "";
     bool output_tpl = false;
     bool comes_with_dia = false;
     string noads = "";
     string output_suffix = "html";
+    string originalexample = "";
     string sheet_path_fragment = args[args.Length - 1];
 
     // Parse commandline arguments
@@ -93,6 +91,14 @@ public class Sheet2Html
 	if (10 < args[i].Length && "--datadir=" == args[i].Substring (0, 10))
 	  System.IO.Directory.SetCurrentDirectory (args[i].Substring (10));
 
+	if (17 < args[i].Length
+	    && "--example-author=" == args[i].Substring (0, 17))
+	  exampleauthor = args[i].Substring (17);
+
+	if (19 < args[i].Length
+	    && "--original-example=" == args[i].Substring (0, 19))
+	  originalexample = args[i].Substring (19);
+
 	if ("--tpl" == args[i])
 	  {
 	    output_tpl = true;
@@ -158,7 +164,11 @@ public class Sheet2Html
 	}
       names = nav.Select (namequery);
       string sheetname = GetValueI18n (language, names);
-      output.WriteElementString ("title", sheetname);
+      XPathNodeIterator sheetdescriptions = nav.Select (sheetdescquery);
+      string sheetdescription = GetValueI18n (language, sheetdescriptions);
+      output.WriteElementString ("title",
+				 "{t}Dia Sheet{/t} " + sheetname + ": " +
+				 sheetdescription);
 
       output.WriteStartElement ("meta");
       output.WriteAttributeString ("http-equiv", "Content-type");
@@ -176,12 +186,20 @@ public class Sheet2Html
 	  output.WriteEndElement ();	// link
 	}
 
-      XPathNodeIterator sheetdescriptions = nav.Select (sheetdescquery);
-      string sheetdescription = GetValueI18n (language, sheetdescriptions);
+
 
       output.WriteStartElement ("meta");
       output.WriteAttributeString ("name", "description");
-      output.WriteAttributeString ("content", sheetdescription);
+      if (comes_with_dia)
+	output.WriteAttributeString ("content",
+				     "{t}Sheet{/t} " + sheetname + ": " +
+				     sheetdescription +
+				     ". {t}Learn more about these objects from Dia's comprehensive toolbox. See a sample diagram and download it in different formats.{/t}");
+      else
+	output.WriteAttributeString ("content",
+				     "{t}Sheet{/t} " + sheetname + ": " +
+				     sheetdescription +
+				     ". {t}Learn more about these objects, how they can be added to your Dia toolbox and how you can draw your diagrams with them. See a sample diagram and download it in different formats.{/t}");
       output.WriteEndElement ();
 
       // CSS sprites
@@ -222,7 +240,8 @@ public class Sheet2Html
       output.WriteStartElement ("img");
       output.WriteAttributeString ("alt", sheetname);
       output.WriteAttributeString ("src",
-				   "images/" + args[args.Length - 1] +
+				   "/shapes/" + args[args.Length - 1] +
+				   "/images/" + args[args.Length - 1] +
 				   ".png");
       output.WriteEndElement ();	// img
 
@@ -233,7 +252,8 @@ public class Sheet2Html
 	  output.WriteStartElement ("li");
 	  output.WriteStartElement ("a");
 	  output.WriteAttributeString ("href",
-				       args[args.Length - 1] + ".zip");
+				       "/shapes/" + args[args.Length - 1] +
+				       "/" + args[args.Length - 1] + ".zip");
 	  output.WriteAttributeString ("class", "track");
 	  output.WriteString (args[args.Length - 1] + ".zip");
 	  output.WriteEndElement ();	// a
@@ -243,18 +263,39 @@ public class Sheet2Html
 	}
       output.WriteStartElement ("li");
       output.WriteStartElement ("a");
-      output.WriteAttributeString ("href", args[args.Length - 1] + ".dia");
+      output.WriteAttributeString ("href",
+				   "/shapes/" + args[args.Length - 1] + "/" +
+				   args[args.Length - 1] + ".dia");
       output.WriteAttributeString ("class", "track");
       output.WriteString (args[args.Length - 1] + ".dia");
       output.WriteEndElement ();	// a
       output.WriteString (" ");
       output.WriteString ("{t}example diagram in Dia format{/t}");
+      if ("" != exampleauthor)
+	{
+	  output.WriteString (", {t 1='" + exampleauthor +
+			      "'}created by %1{/t}");
+	}
+      if ("" != originalexample)
+	{
+	  output.WriteString
+	    (". {capture name=original_file assign=original_file}");
+	  output.WriteStartElement ("a");
+	  output.WriteAttributeString ("href", originalexample);
+	  output.WriteAttributeString ("target", "_blank");
+	  output.WriteAttributeString ("rel", "nofollow");
+	  output.WriteString ("{t}original file{/t}");
+	  output.WriteEndElement ();	// a
+	  output.WriteString
+	    ("{/capture}{t escape=no 1=$original_file}See the %1{/t}");
+	}
       output.WriteEndElement ();	// li
 
       output.WriteStartElement ("li");
       output.WriteStartElement ("a");
       output.WriteAttributeString ("href",
-				   "images/" + args[args.Length - 1] +
+				   "/shapes/" + args[args.Length - 1] +
+				   "/images/" + args[args.Length - 1] +
 				   ".svg");
       output.WriteAttributeString ("class", "track");
       output.WriteString (args[args.Length - 1] + ".svg");
